==> applet-service-2.0.0-20201010.075138-23-sources.jar: com/bizvane/appletservice/models/bo/AppletBrandFunctionBo.java <==
package com.bizvane.appletservice.models.bo;


/**
 * @author liufq
 */
public class AppletBrandFunctionBo {
    private String functionName;
    private String functionUrl;
    private String functionLogo;
    private Integer sort;
    private Long appletFunctionId;
    private int choice;
    private Long brandId;
    private String functionLogoOne;
    private boolean customerText;
    private String customerUrl;
    private String functionCode;
    private String oderMemberCode;
    private String modular;
    /**
     * 活动红点提示
     */
    private Boolean activityDisplayIdentification = false;
    /**
     * 任务类型
     */
    private Integer typeUrl;
    /**
     * 微商城 appId
     */
    private String appId;

    private String customFunctionName;
    private Boolean customerName;

    public String getCustomFunctionName() {
        return customFunctionName;
    }

    public void setCustomFunctionName(String customFunctionName) {
        this.customFunctionName = customFunctionName;
    }

    public Boolean getCustomerName() {
        return customerName;
    }

    public void setCustomerName(Boolean customerName) {
        this.customerName = customerName;
    }

    public String getOderMemberCode() {
        return oderMemberCode;
    }

    public void setOderMemberCode(String oderMemberCode) {
        this.oderMemberCode = oderMemberCode;
    }

    public Integer getTypeUrl() {
        return typeUrl;
    }

    public void setTypeUrl(Integer typeUrl) {
        this.typeUrl = typeUrl;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public boolean isCustomerText() {
        return customerText;
    }

    public void setCustomerText(boolean customerText) {
        this.customerText = customerText;
    }

    public String getFunctionName() {
        return functionName;
    }

    public void setFunctionName(String functionName) {
        this.functionName = functionName;
    }

    public String getFunctionUrl() {
        return functionUrl;
    }

    public void setFunctionUrl(String functionUrl) {
        this.functionUrl = functionUrl;
    }

    public String getFunctionLogo() {
        return functionLogo;
    }

    public void setFunctionLogo(String functionLogo) {
        this.functionLogo = functionLogo;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Long getAppletFunctionId() {
        return appletFunctionId;
    }

    public void setAppletFunctionId(Long appletFunctionId) {
        this.appletFunctionId = appletFunctionId;
    }

    public int getChoice() {
        return choice;
    }

    public void setChoice(int choice) {
        this.choice = choice;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getFunctionLogoOne() {
        return functionLogoOne;
    }

    public void setFunctionLogoOne(String functionLogoOne) {
        this.functionLogoOne = functionLogoOne;
    }

    public String getFunctionCode() {
        return functionCode;
    }

    public void setFunctionCode(String functionCode) {
        this.functionCode = functionCode;
    }

    public String getModular() {
        return modular;
    }

    public void setModular(String modular) {
        this.modular = modular;
    }

    public Boolean getActivityDisplayIdentification() {
        return activityDisplayIdentification;
    }

    public void setActivityDisplayIdentification(Boolean activityDisplayIdentification) {
        this.activityDisplayIdentification = activityDisplayIdentification;
    }

    public String getCustomerUrl() {
        return customerUrl;
    }

    public void setCustomerUrl(String customerUrl) {
        this.customerUrl = customerUrl;
    }
}

==> applet-service-2.0.2-20210818.015448-9-sources.jar: com/bizvane/appletservice/models/bo/AppletBrandFunctionBo.java <==
package com.bizvane.appletservice.models.bo;


/**
 * @author liufq
 */
public class AppletBrandFunctionBo {
    private String functionName;
    private String functionUrl;
    private String functionLogo;
    private Integer sort;
    private Long appletFunctionId;
    private int choice;
    private Long brandId;
    private String functionLogoOne;
    private boolean customerText;
    private String customerUrl;
    /**
     * 链接类型 1:功能页面  2:自定义链接 3:互动营销
     */
    private Integer urlType;

    /**
     * 链接类型扩展 1:链接到我的小程序 2:链接到其他小程序 3:链接到H5链接
     */
    private Integer urlTypeExtend;
    /**
     * 菜单t_applet_brand_function_rel表中appId functionAppId
     */
    private String functionAppId;
    private String functionCode;
    private String oderMemberCode;
    private String modular;
    /**
     * 活动红点提示
     */
    private Boolean activityDisplayIdentification = false;
    /**
     * 任务类型
     */
    private Integer typeUrl;
    /**
     * 微商城 appId
     */
    private String appId;

    private String customFunctionName;
    private Boolean customerName;

    public String getCustomFunctionName() {
        return customFunctionName;
    }

    public void setCustomFunctionName(String customFunctionName) {
        this.customFunctionName = customFunctionName;
    }

    public Boolean getCustomerName() {
        return customerName;
    }

    public void setCustomerName(Boolean customerName) {
        this.customerName = customerName;
    }

    public String getOderMemberCode() {
        return oderMemberCode;
    }

    public void setOderMemberCode(String oderMemberCode) {
        this.oderMemberCode = oderMemberCode;
    }

    public Integer getTypeUrl() {
        return typeUrl;
    }

    public void setTypeUrl(Integer typeUrl) {
        this.typeUrl = typeUrl;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public boolean isCustomerText() {
        return customerText;
    }

    public void setCustomerText(boolean customerText) {
        this.customerText = customerText;
    }

    public String getFunctionName() {
        return functionName;
    }

    public void setFunctionName(String functionName) {
        this.functionName = functionName;
    }

    public String getFunctionUrl() {
        return functionUrl;
    }

    public void setFunctionUrl(String functionUrl) {
        this.functionUrl = functionUrl;
    }

    public String getFunctionLogo() {
        return functionLogo;
    }

    public void setFunctionLogo(String functionLogo) {
        this.functionLogo = functionLogo;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Long getAppletFunctionId() {
        return appletFunctionId;
    }

    public void setAppletFunctionId(Long appletFunctionId) {
        this.appletFunctionId = appletFunctionId;
    }

    public int getChoice() {
        return choice;
    }

    public void setChoice(int choice) {
        this.choice = choice;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getFunctionLogoOne() {
        return functionLogoOne;
    }

    public void setFunctionLogoOne(String functionLogoOne) {
        this.functionLogoOne = functionLogoOne;
    }

    public String getFunctionCode() {
        return functionCode;
    }

    public void setFunctionCode(String functionCode) {
        this.functionCode = functionCode;
    }

    public String getModular() {
        return modular;
    }

    public void setModular(String modular) {
        this.modular = modular;
    }

    public Boolean getActivityDisplayIdentification() {
        return activityDisplayIdentification;
    }

    public void setActivityDisplayIdentification(Boolean activityDisplayIdentification) {
        this.activityDisplayIdentification = activityDisplayIdentification;
    }

    public String getCustomerUrl() {
        return customerUrl;
    }

    public void setCustomerUrl(String customerUrl) {
        this.customerUrl = customerUrl;
    }

    public Integer getUrlType() {
        return urlType;
    }

    public void setUrlType(Integer urlType) {
        this.urlType = urlType;
    }

    public Integer getUrlTypeExtend() {
        return urlTypeExtend;
    }

    public void setUrlTypeExtend(Integer urlTypeExtend) {
        this.urlTypeExtend = urlTypeExtend;
    }

    public String getFunctionAppId() {
        return functionAppId;
    }

    public void setFunctionAppId(String functionAppId) {
        this.functionAppId = functionAppId;
    }
}
